@@ -1,5 +1,9 @@
+import decimal
 import os.path
+import uuid
 from collections import ChainMap
+from datetime import date, datetime
+from json.encoder import JSONEncoder
 from string import Template
 from typing import Any, Dict, List, Mapping, Tuple, Union
 
@@ -26,8 +30,15 @@ except ImportError:
     from json.decoder import JSONDecodeError
 
 
-__all__ = ["__version__", "decode_bytes", "substitute", "merge_vars", "convert_vars"]
-__version__ = "1.22.1"
+__all__ = [
+    "__version__",
+    "decode_bytes",
+    "substitute",
+    "merge_vars",
+    "convert_vars",
+    "PayloadEncoder",
+]
+__version__ = "1.23.1"
 
 
 def substitute(
@@ -257,16 +268,7 @@ def convert_vars(value: List[str]) -> Dict[str, Any]:  # noqa: C901
             if ":" in k:
                 k, typ = k.rsplit(":", 1)
                 try:
-                    if typ == "str":
-                        pass
-                    elif typ == "int":
-                        v = int(v)
-                    elif typ == "float":
-                        v = float(v)
-                    elif typ == "bytes":
-                        v = v.encode("utf-8")
-                    else:
-                        raise ValueError("var supports only: str, int, float and bytes")
+                    v = convert_to_type(typ, v)
                 except (TypeError, UnicodeEncodeError):
                     raise ValueError("var cannot convert value to required type")
             var[k] = v
@@ -276,3 +278,49 @@ def convert_vars(value: List[str]) -> Dict[str, Any]:  # noqa: C901
             raise ValueError("var needs to be in the format name[:type]=value")
 
     return var
+
+
+def convert_to_type(type: str, val: str) -> Union[str, int, float, bytes]:
+    """
+    Converts a value to a provided type. If `type` is None, then the original string is
+    returned, else the val is coerced into the provided type. An exception is thrown
+    if the type is not supported.
+
+    :param type: str representing what type to convert `val` to
+    :param val: str representing the variable loaded in to configuration
+    :returns: Union[str, int, float, bytes] representing the converted value
+    """
+    if type is None or type == "str":
+        return val
+    elif type == "int":
+        return int(val)
+    elif type == "float":
+        return float(val)
+    elif type == "bytes":
+        return val.encode("utf-8")
+    else:
+        raise ValueError("variables can only be: str, int, float, or bytes")
+
+
+class PayloadEncoder(JSONEncoder):
+    """
+    Extension of the base JSONEncoder to support serialising objects commonly passed
+    around in Chaos Toolkit function payloads
+
+    Currently supports:
+    - datetime/date objects
+    - UUID objects
+    - Decimal objects
+    - Exception objects
+    """
+
+    def default(self, obj) -> str:
+        if isinstance(obj, (datetime, date)):
+            return obj.isoformat()
+        elif isinstance(obj, uuid.UUID):
+            return str(obj)
+        elif isinstance(obj, decimal.Decimal):
+            return str(obj)
+        elif isinstance(obj, Exception):
+            return f"An exception was raised: {obj.__class__.__name__}('{str(obj)}')"
+        return JSONEncoder.default(self, obj)
